from sys import platform
from os import stat,chmod
from os.path import join,expanduser
from setuptools.command.install import install

#修改project_name即可打包，其他地方不用修改
project_name = "kdui2py"

class install_cmd(install):
    def run(self):
        install.run(self)
        try :
            if platform =="win32" :
                    script_file =  join(self._get_desktop_folder(),project_name + '.bat')
                    with open(script_file, "w") as f:
                        f.write("@echo off\r\nstart " + project_name + ".exe")
            elif platform == "linux":
                    script_file =  join(self._get_desktop_folder(),project_name + '.sh')
                    with open(script_file, "w") as f:
                        f.write("#!/bin/sh\n" + project_name)
                        st = stat(script_file)
                        chmod(script_file, st.st_mode | stat.S_IEXEC)
        except Exception as e:
            print("can not create start script." + str(e))
    def _get_desktop_folder(self):
        import subprocess
        try:
            return subprocess.check_output(['xdg-user-dir',
                                            'DESKTOP']).decode('utf-8').strip()
        except Exception:
            return join(expanduser('~'), 'Desktop')   



'''
Created on 2019年4月6日

@author: bkd
'''
import sys
import optparse
from os import walk,listdir
from os.path import expanduser,dirname,join,splitext,basename
from PyQt5.QtGui import QTextCursor, QIcon
from PyQt5.uic import loadUi
from PyQt5.QtCore import pyqtSlot
from PyQt5.QtWidgets import  QWidget,QApplication,QFileDialog, QMessageBox
from PyQt5.uic.driver import Driver
from .fileutil import get_file_realpath
from .kdui2py_ui import Ui_Form

class kdui2py(QWidget,Ui_Form):

    def __init__ (self):
        super().__init__()
        self.setupUi(self)
        self.setWindowIcon(QIcon(get_file_realpath("logo.jpg")))
        self.last_dir = None
    @pyqtSlot()
    def on_pb_convert_single_file_clicked(self):
        seleted_file,_ = QFileDialog.getOpenFileName(self, '转换单个文件', self.get_last_dir(), '*.ui', '')
        self.last_dir = dirname(seleted_file)
        output_file = self.convert_single_file(seleted_file)
        self.tb_result.append("转换成功，{} -> {}".format(basename(seleted_file), output_file))
        self.tb_result.moveCursor(QTextCursor.End)
        self.tb_result.append("\n")

    @pyqtSlot()
    def on_pb_single_dir_clicked(self):
        seleted_dir = QFileDialog.getExistingDirectory(self, '转换单个目录', self.get_last_dir())
        self.last_dir = seleted_dir
        
        files = listdir(seleted_dir)
        for file in files :
            if file.endswith(".ui"):
                absolute_path = join(seleted_dir,file)
                output_file = self.convert_single_file(absolute_path)
                self.tb_result.append("转换成功，{} -> {}".format(file, output_file))
                self.tb_result.moveCursor(QTextCursor.End)
        self.tb_result.append("\n")
    @pyqtSlot()
    def on_pb_dir_and_subdir_clicked(self):
        seleted_dir = QFileDialog.getExistingDirectory(self, '转换单个目录', self.get_last_dir())
        self.last_dir = seleted_dir
#         for dirpath,dirnames,filenames in walk(seleted_dir):
        for dirpath,_,filenames in walk(seleted_dir):
            for file in filenames:
                if file.endswith(".ui"):
                    absolute_path = join(dirpath,file)
                    output_file = self.convert_single_file(absolute_path)
                    self.tb_result.append("转换成功，{} -> {}".format(file, output_file))
                    self.tb_result.moveCursor(QTextCursor.End)
        self.tb_result.append("\n")
#     预览UI文件
    @pyqtSlot()
    def on_pb_preview_clicked(self):
        seleted_file,_ = QFileDialog.getOpenFileName(self, '转换单个文件', expanduser("~"), '*.ui', '')
        try:
            self.preview_widget = loadUi(seleted_file)
            self.preview_widget.show()
        except Exception as e:
            QMessageBox.warning(self, "预览文件失败", str(e), QMessageBox.Ok)

#             获取上一次打开的目录
    def get_last_dir(self):
        if self.last_dir :
            return self.last_dir
        else :
            return expanduser("~")
        
#         转换单个文件
    def convert_single_file(self,filename,preview = False):
        if filename :
            base_name = basename(filename)
            output_file = join(dirname(filename),splitext(base_name)[0]+self.le_suffix.text() +".py")
#             complete sample : opts: {'preview': False, 'output': '/tmp/r.oo', 'execute': False, 'debug': False, 'indent': 4, 'import_from': None, 'from_imports': False, 'resource_suffix': '_ui'}
            opts = optparse.Values()
            opts.ensure_value("preview", preview)
            opts.ensure_value("execute", False)
            opts.ensure_value("debug", False)
            opts.ensure_value("indent", 4)
            opts.ensure_value("from_imports", False)
            opts.ensure_value("import_from", None)
            opts.ensure_value("resource_suffix", "_rc")
            opts.ensure_value("output", output_file)
            args =filename
            driver = Driver(opts,args)
            try:
                driver.invoke()
#                 print(filename,output_file,exit_status)
#                 QMessageBox.information(self, "转换成功", str(exit_status), QMessageBox.Ok)
                return output_file
            except IOError as e:
                QMessageBox.warning(self, "转换异常", str(e), QMessageBox.Ok)
def main():
    app = QApplication(sys.argv)
    win = kdui2py()
    win.show()
    sys.exit(app.exec_())
if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/bkd/pyqt/kdui2py/kdui2py/kdui2py.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(402, 272)
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.pb_convert_single_file = QtWidgets.QPushButton(Form)
        self.pb_convert_single_file.setObjectName("pb_convert_single_file")
        self.gridLayout.addWidget(self.pb_convert_single_file, 1, 0, 1, 1)
        self.pb_single_dir = QtWidgets.QPushButton(Form)
        self.pb_single_dir.setObjectName("pb_single_dir")
        self.gridLayout.addWidget(self.pb_single_dir, 1, 2, 1, 1)
        self.pb_dir_and_subdir = QtWidgets.QPushButton(Form)
        self.pb_dir_and_subdir.setObjectName("pb_dir_and_subdir")
        self.gridLayout.addWidget(self.pb_dir_and_subdir, 1, 3, 1, 1)
        self.tb_result = QtWidgets.QTextBrowser(Form)
        self.tb_result.setObjectName("tb_result")
        self.gridLayout.addWidget(self.tb_result, 2, 0, 1, 4)
        self.pb_preview = QtWidgets.QPushButton(Form)
        self.pb_preview.setObjectName("pb_preview")
        self.gridLayout.addWidget(self.pb_preview, 1, 1, 1, 1)
        self.label = QtWidgets.QLabel(Form)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.le_suffix = QtWidgets.QLineEdit(Form)
        self.le_suffix.setObjectName("le_suffix")
        self.gridLayout.addWidget(self.le_suffix, 0, 1, 1, 3)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "kdui2py"))
        self.pb_convert_single_file.setText(_translate("Form", "单个文件"))
        self.pb_single_dir.setText(_translate("Form", "单个目录"))
        self.pb_dir_and_subdir.setText(_translate("Form", "目录及其子目录"))
        self.pb_preview.setText(_translate("Form", "预览UI文件"))
        self.label.setText(_translate("Form", "文件名后缀："))
        self.le_suffix.setText(_translate("Form", "_ui"))

